@@ -1,7 +1,7 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-03 10:51:08
-# @Last Modified time: 2021-02-24 20:04:11
+# @Last Modified time: 2021-03-26 14:46:17
 # @github: https://github.com/longfengpili
 
 #!/usr/bin/env python3
@@ -13,10 +13,7 @@ import os
 from datetime import datetime, date, timedelta
 
 import logging
-import logging.config
-from pydbapi.conf import LOGGING_CONFIG
-logging.config.dictConfig(LOGGING_CONFIG)
-sqllogger = logging.getLogger('sql')
+sqllogger = logging.getLogger(__name__)
 
 
 class SqlParse(object):
